@@ -1,4 +1,4 @@
-// Copyright (C) 2006-2007 David Sugar, Tycho Softworks.
+// Copyright (C) 2006-2008 David Sugar, Tycho Softworks.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -78,7 +78,7 @@ public:
 	enum {OFFLINE = 0, IDLE, BUSY, AWAY, DND} status;
 	enum {EXPIRED = 0, USER, GATEWAY, SERVICE, REJECT, REFER, TEMPORARY, REGISTRATION} type;
 	bool hidden;
-	unsigned rid;				// registry remap or peer id 
+	int rid;				// registry remap or peer id 
 	unsigned ext;				// 0 or extnum
 	unsigned count;				// active regs count
 	volatile unsigned inuse;	// in use for call count
