@@ -1,4 +1,4 @@
-// Copyright (C) 2006-2007 David Sugar, Tycho Softworks.
+// Copyright (C) 2006-2008 David Sugar, Tycho Softworks.
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -747,7 +747,7 @@ untrusted:
 	if(via_host)
 		debug(2, "challenge required for %s:%u", via_host, via_port);
 	else
-		debug(2, "challenge request required", 0);
+		debug(2, "%s", "challenge request required");
 	challenge();
 	return false;
 }
@@ -877,7 +877,7 @@ rewrite:
 	reginfo = registry::dialing(target);
 	server::getDialing(target, dialed);
 
-	debug(4, "rewrite process; registry=%p, dialed=%p\n", reginfo, dialed.keys);
+	debug(4, "rewrite process; registry=%p, dialed=%p\n", (void *)reginfo, (void *)dialed.keys);
 
 	if(!reginfo && !dialed.keys)
 		goto routing;
